@@ -4,6 +4,8 @@ from django.db import models
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 
+from feincms.translations import short_language_code
+
 from elephantblog.models import Category, Entry
 from elephantblog.utils import entry_list_lookup_related
 
@@ -22,6 +24,8 @@ class BlogEntryListContent(models.Model):
     featured_only = models.BooleanField(_('featured only'), blank=True, default=False,
         help_text=_('Only show articles marked as featured'))
 
+    only_active_language = False
+
     class Meta:
         abstract = True
         verbose_name = _('Blog entry list')
@@ -36,6 +40,9 @@ class BlogEntryListContent(models.Model):
         if self.category:
             entries = entries.filter(categories=self.category)
 
+        if self.only_active_language:
+            entries = entries.filter(language__istartswith=short_language_code())
+
         if self.paginate_by:
             paginator = Paginator(entries, self.paginate_by)
             page = request.GET.get('page', 1)
@@ -54,3 +61,23 @@ class BlogEntryListContent(models.Model):
         if self.featured_only:
             template_names.insert(0, 'entry_list_featured.html')
         return render_to_string(template_names, { 'content': self })
+
+
+class BlogCategoryListContent(models.Model):
+    show_empty_categories = models.BooleanField(_('show empty categories?'))
+
+    class Meta:
+        abstract = True
+        verbose_name = _('Blog category list')
+        verbose_name_plural = _('Blog category lists')
+
+    def render(self, **kwargs):
+        if self.show_empty_categories:
+            categories = Category.objects.all()
+        else:
+            categories = Category.objects.exclude(blogentries__isnull=True)
+
+        return render_to_string('content/elephantblog/category_list.html', {
+            'content': self,
+            'categories': categories,
+            }, context_instance=kwargs.get('context'))
