@@ -6,4 +6,7 @@ from taggit.managers import TaggableManager
 def register(cls, admin_cls):
     cls.add_to_class('tags', TaggableManager(
         help_text=_('A comma-separated list of tags.'), blank=True))
-    admin_cls.fieldsets[0][1].get('fields').append('tags')
+
+    if admin_cls:
+        if hasattr(admin_cls, 'add_extension_options'):
+            admin_cls.add_extension_options('tags')
