@@ -8,6 +8,7 @@ from feincms import translations
 from feincms.admin import item_editor
 from feincms.management.checker import check_database_schema
 from feincms.models import Base
+from feincms.module.mixins import ContentModelMixin
 from feincms.utils.managers import ActiveAwareContentManagerMixin
 from feincms.utils.queryset_transform import TransformQuerySet
 try:
@@ -19,6 +20,7 @@ except ImportError:
     now = datetime.now
 
 
+
 class Category(models.Model, translations.TranslatedObjectMixin):
     """
     Category is language-aware and connected to the Entry model via
@@ -83,14 +85,14 @@ EntryManager.add_to_active_filters(
 
 
 
-class Entry(Base):
+class Entry(Base, ContentModelMixin):
     is_active = models.BooleanField(_('is active'), default=True, db_index=True)
     is_featured = models.BooleanField(_('is featured'), default=False, db_index=True)
 
     title = models.CharField(_('title'), max_length=100)
     slug = models.SlugField(_('slug'), max_length=100, unique_for_date='published_on')
-    author = models.ForeignKey(User, related_name='blogentries', verbose_name=_('author'))
-
+    author = models.ForeignKey(User, related_name='blogentries',
+                limit_choices_to={'is_staff': True}, verbose_name=_('author'))
     published_on = models.DateTimeField(_('published on'), blank=True, null=True, default=now,
         help_text=_('Will be filled in automatically when entry gets published.'), db_index=True)
     last_changed = models.DateTimeField(_('last change'), auto_now=True, editable=False)
@@ -118,6 +120,7 @@ class Entry(Base):
             self.published_on = now()
 
         super(Entry, self).save(*args, **kwargs)
+    save.alters_data = True
 
     @models.permalink
     def get_absolute_url(self):
@@ -137,12 +140,13 @@ class Entry(Base):
     def register_extension(cls, register_fn):
         register_fn(cls, EntryAdmin)
 
+
 signals.post_syncdb.connect(check_database_schema(Entry, __name__), weak=False)
 
 
 def entry_admin_update_fn(new_state, new_state_dict, short_description=None):
     def _fn(self, request, queryset):
-        rows_updated = queryset.update(**new_state)
+        rows_updated = queryset.update(**new_state_dict)
 
         self.message_user(request, ungettext(
             'One entry was successfully marked as %(state)s',
@@ -176,14 +180,8 @@ class EntryAdmin(item_editor.ItemEditor):
                 'categories',
             ]
         }],
+        [None, {
+            'fields': [],
+        }],
         item_editor.FEINCMS_CONTENT_FIELDSET,
     ]
-
-    @classmethod
-    def add_extension_options(cls, *f):
-        if isinstance(f[-1], dict):     # called with a fieldset
-            cls.fieldsets.insert(cls.fieldset_insertion_index, f)
-            f[1]['classes'] = list(f[1].get('classes', []))
-            f[1]['classes'].append('collapse')
-        else:   # assume called with "other" fields
-            cls.fieldsets[0][1]['fields'].extend(f)
