@@ -1,13 +1,17 @@
 import datetime
 
 from django.conf import settings
+from django.db.models import FieldDoesNotExist
 from django.http import Http404, HttpResponse
 from django.db import models
+from django.db.models.fields import FieldDoesNotExist
 from django.shortcuts import get_object_or_404
 from django.utils.cache import add_never_cache_headers
+from django.utils.translation import ugettext as _
 from django.views.generic import dates
 
-from feincms.translations import short_language_code
+from feincms.module.mixins import ContentObjectMixin
+from django.utils.translation import get_language
 
 from elephantblog.models import Category, Entry
 from elephantblog.utils import entry_list_lookup_related
@@ -58,7 +62,27 @@ class ElephantblogMixin(object):
             context, **response_kwargs)
 
 
-class ArchiveIndexView(ElephantblogMixin, dates.ArchiveIndexView):
+class TranslationMixin(object):
+    """
+    #: Determines, whether list views should only display entries from
+    #: the active language at a time. Requires the translations extension.
+    """
+    only_active_language = True
+
+    def get_queryset(self):
+        queryset = super(TranslationMixin, self).get_queryset()
+        try:
+            queryset.model._meta.get_field_by_name('language')
+        except FieldDoesNotExist:
+            return queryset
+        else:
+            if self.only_active_language:
+                return queryset.filter(language=get_language())
+            else:
+                return queryset
+
+
+class ArchiveIndexView(TranslationMixin, ElephantblogMixin, dates.ArchiveIndexView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     date_field = 'published_on'
@@ -66,7 +90,7 @@ class ArchiveIndexView(ElephantblogMixin, dates.ArchiveIndexView):
     allow_empty = True
 
 
-class YearArchiveView(ElephantblogMixin, dates.YearArchiveView):
+class YearArchiveView(TranslationMixin, ElephantblogMixin, dates.YearArchiveView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     date_field = 'published_on'
@@ -74,7 +98,7 @@ class YearArchiveView(ElephantblogMixin, dates.YearArchiveView):
     template_name_suffix = '_archive'
 
 
-class MonthArchiveView(ElephantblogMixin, dates.MonthArchiveView):
+class MonthArchiveView(TranslationMixin, ElephantblogMixin, dates.MonthArchiveView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     month_format = '%m'
@@ -82,7 +106,7 @@ class MonthArchiveView(ElephantblogMixin, dates.MonthArchiveView):
     template_name_suffix = '_archive'
 
 
-class DayArchiveView(ElephantblogMixin, dates.DayArchiveView):
+class DayArchiveView(TranslationMixin, ElephantblogMixin, dates.DayArchiveView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     month_format = '%m'
@@ -90,11 +114,13 @@ class DayArchiveView(ElephantblogMixin, dates.DayArchiveView):
     template_name_suffix = '_archive'
 
 
-class DateDetailView(ElephantblogMixin, dates.DateDetailView):
+class DateDetailView(ContentObjectMixin, ElephantblogMixin,
+        dates.DateDetailView):
     paginator_class = paginator.Paginator
     paginate_by = PAGINATE_BY
     month_format = '%m'
     date_field = 'published_on'
+    context_object_name = 'entry'
 
     def get_queryset(self):
         if (self.request.user.is_authenticated() and self.request.user.is_staff
@@ -102,18 +128,6 @@ class DateDetailView(ElephantblogMixin, dates.DateDetailView):
             return Entry.objects.all()
         return Entry.objects.active()
 
-    def get(self, request, *args, **kwargs):
-        self.object = self.get_object()
-        response = self.prepare()
-        if response:
-            return response
-
-        response = self.render_to_response(self.get_context_data(object=self.object))
-        return self.finalize(response)
-
-    def post(self, request, *args, **kwargs):
-        return self.get(request, *args, **kwargs)
-
     def _make_date_lookup_arg(self, value):
         """
         Available in Django >= 1.5 only
@@ -182,58 +196,14 @@ class DateDetailView(ElephantblogMixin, dates.DateDetailView):
 
         return super(dates.BaseDetailView, self).get_object(queryset=qs)
 
-    def prepare(self):
-        """
-        Prepare / pre-process content types. If this method returns anything,
-        it is treated as a ``HttpResponse`` and handed back to the visitor.
-        """
-
-        http404 = None     # store eventual Http404 exceptions for re-raising,
-                           # if no content type wants to handle the current self.request
-        successful = False # did any content type successfully end processing?
-
-        for content in self.object.content.all_of_type(
-                tuple(self.object._feincms_content_types_with_process)):
-            try:
-                r = content.process(self.request, view=self)
-                if r in (True, False):
-                    successful = r
-                elif r:
-                    return r
-            except Http404, e:
-                http404 = e
-
-        if not successful:
-            if http404:
-                # re-raise stored Http404 exception
-                raise http404
-
-            """ XXX This does not make sense in this context, does it?
-            if not settings.FEINCMS_ALLOW_EXTRA_PATH and \
-                    self.request._feincms_extra_context['extra_path'] != '/':
-                raise Http404
-            """
-
-    def finalize(self, response):
-        """
-        Runs finalize() on content types having such a method, adds headers and
-        returns the final response.
-        """
-
-        if not isinstance(response, HttpResponse):
-            # For example in the case of inheritance 2.0
-            return response
-
-        for content in self.object.content.all_of_type(tuple(self.object._feincms_content_types_with_finalize)):
-            r = content.finalize(self.request, response)
-            if r:
-                return r
-
-        # Add never cache headers in case frontend editing is active
-        if hasattr(self.request, "session") and self.request.session.get('frontend_editing', False):
-            add_never_cache_headers(response)
-
-        return response
+    def dispatch(self, request, *args, **kwargs):
+        if request.method.lower() not in self.http_method_names:
+            return self.http_method_not_allowed(request, *args, **kwargs)
+        self.request = request
+        self.args = args
+        self.kwargs = kwargs
+        self.object = self.get_object()
+        return self.handler(request, *args, **kwargs)
 
 
 class CategoryArchiveIndexView(ArchiveIndexView):
